@@ -17,10 +17,10 @@
 # limitations under the License.
 #
 
-require 'chef-config/config'
-require 'ohai/exception'
-require 'ohai/log'
-require 'ohai/plugin_config'
+require "chef-config/config"
+require "ohai/exception"
+require "ohai/log"
+require "ohai/plugin_config"
 
 module Ohai
   Config = ChefConfig::Config
@@ -30,27 +30,29 @@ module Ohai
   class Config
     # These methods need to be defined before they are used as config defaults,
     # otherwise they will get method_missing'd to nil.
-    private
-    def self.default_hints_path
-      [ ChefConfig::Config.platform_specific_path('/etc/chef/ohai/hints') ]
-    end
 
-    def self.default_plugin_path
-      [ File.expand_path(File.join(File.dirname(__FILE__), 'plugins')) ]
-    end
-
-    public
-    # Copy deprecated configuration options into the ohai config context.
-    def self.merge_deprecated_config
-      [ :hints_path, :plugin_path ].each do |option|
-        if has_key?(option) && send(option) != send("default_#{option}".to_sym)
-          Ohai::Log.warn(option_deprecated(option))
+    class << self
+      def merge_deprecated_config
+        [ :hints_path, :plugin_path ].each do |option|
+          if has_key?(option) && send(option) != send("default_#{option}".to_sym)
+            Ohai::Log.warn(option_deprecated(option))
+          end
         end
+
+        ohai.merge!(configuration)
       end
 
-      ohai.merge!(configuration)
+      def default_hints_path
+        [ ChefConfig::Config.platform_specific_path("/etc/chef/ohai/hints") ]
+      end
+
+      def default_plugin_path
+        [ File.expand_path(File.join(File.dirname(__FILE__), "plugins")) ]
+      end
     end
 
+    # Copy deprecated configuration options into the ohai config context.
+
     # Keep "old" config defaults around so anyone calling Ohai::Config[:key]
     # won't be broken. Also allows users to append to configuration options
     # (e.g., Ohai::Config[:plugin_path] << some_path) in their config files.
@@ -68,7 +70,7 @@ module Ohai
       :disabled_plugins,
       :log_level,
       :log_location,
-      :version
+      :version,
     ].each do |option|
       # https://docs.chef.io/config_rb_client.html#ohai-settings
       # hints_path and plugin_path are intentionally excluded here; warnings for
@@ -83,8 +85,11 @@ module Ohai
         # Furthermore, when the top-level config settings are removed we will
         # need to ensure that Ohai.config[:log_level] can be set by writing
         # log_level in a configuration file for consistent behavior with chef.
-        deprecation_warning = [ :log_level, :log_location ].include?(value) ?
-          option_might_be_deprecated(option) : option_deprecated(option)
+        deprecation_warning = if [ :log_level, :log_location ].include?(value)
+                                option_might_be_deprecated(option)
+                              else
+                                option_deprecated(option)
+                              end
         Ohai::Log.warn(deprecation_warning)
         value
       end
@@ -99,26 +104,27 @@ module Ohai
       default :plugin_path, Ohai::Config.default_plugin_path
     end
 
-    private
-    def self.option_deprecated(option)
-      <<-EOM.chomp!.gsub("\n", " ")
+    class << self
+      def option_deprecated(option)
+        <<-EOM.chomp!.tr("\n", " ")
 Ohai::Config[:#{option}] is set. Ohai::Config[:#{option}] is deprecated and will
 be removed in future releases of ohai. Use ohai.#{option} in your configuration
 file to configure :#{option} for ohai.
-EOM
-    end
+        EOM
+      end
 
-    def self.option_might_be_deprecated(option)
-      option_deprecated(option) + <<-EOM.chomp!.gsub("\n", " ")
+      def option_might_be_deprecated(option)
+        option_deprecated(option) + <<-EOM.chomp!.tr("\n", " ")
  If your configuration file is used with other applications which configure
 :#{option}, and you have not configured Ohai::Config[:#{option}], you may
 disregard this warning.
-EOM
+        EOM
+      end
     end
   end
 
   # Shortcut for Ohai::Config.ohai
   def self.config
-    Config::ohai
+    Config.ohai
   end
 end
