@@ -18,10 +18,11 @@
 # limitations under the License.
 #
 
-require 'ohai/mixin/os'
-require 'ohai/mixin/command'
-require 'ohai/mixin/seconds_to_human'
-require 'ohai/hints'
+require "ohai/mixin/os"
+require "ohai/mixin/command"
+require "ohai/mixin/seconds_to_human"
+require "ohai/hints"
+require "ohai/util/file_helper"
 
 module Ohai
 
@@ -81,6 +82,7 @@ module Ohai
       include Ohai::Mixin::OS
       include Ohai::Mixin::Command
       include Ohai::Mixin::SecondsToHuman
+      include Ohai::Util::FileHelper
 
       attr_reader :data
 
@@ -117,7 +119,7 @@ module Ohai
 
       def each(&block)
         @data.each do |key, value|
-          block.call(key, value)
+          yield(key, value)
         end
       end
 
@@ -125,7 +127,9 @@ module Ohai
         @data.has_key?(name)
       end
 
-      alias :attribute? :has_key?
+      def attribute?(name, *keys)
+        !safe_get_attribute(name, *keys).nil?
+      end
 
       def set(name, *value)
         set_attribute(name, *value)
@@ -155,8 +159,8 @@ module Ohai
         @data[name]
       end
 
-      def get_attribute(name)
-        @data[name]
+      def get_attribute(name, *keys)
+        safe_get_attribute(name, *keys)
       end
 
       def hint?(name)
@@ -171,7 +175,7 @@ module Ohai
           raise e
         rescue => e
           Ohai::Log.debug("Plugin #{self.name} threw #{e.inspect}")
-          e.backtrace.each { |line| Ohai::Log.debug( line )}
+          e.backtrace.each { |line| Ohai::Log.debug( line ) }
         end
       end
 
@@ -183,6 +187,18 @@ module Ohai
 
       private
 
+      def safe_get_attribute(*keys)
+        keys.inject(@data) do |attrs, key|
+          unless attrs.nil? || attrs.is_a?(Array) || attrs.is_a?(Hash)
+            raise TypeError.new("Expected Hash but got #{attrs.class}.")
+          end
+          attrs[key]
+        end
+      rescue NoMethodError
+        # NoMethodError occurs when trying to access a key on nil
+        nil
+      end
+
       def Array18(*args)
         return nil if args.empty?
         return args.first if args.length == 1
