@@ -1,6 +1,6 @@
 #
-# Author:: Adam Jacob (<adam@opscode.com>)
-# Copyright:: Copyright (c) 2008 Opscode, Inc.
+# Author:: Adam Jacob (<adam@chef.io>)
+# Copyright:: Copyright (c) 2008-2016 Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -28,5 +28,6 @@ module Ohai
     class DependencyCycle < Error; end
     class DependencyNotFound < Error; end
     class AttributeSyntaxError < Error; end
+    class PluginConfigError < Error; end
   end
 end
