@@ -17,33 +17,35 @@
 # limitations under the License.
 #
 
-require 'ffi_yajl'
+require "ffi_yajl"
 
 module Ohai
   module Hints
     def self.refresh_hints
-      @hints = Hash.new
+      @hints = {}
+    end
+
+    def self.parse_hint_file(filename)
+      json_parser = FFI_Yajl::Parser.new
+      hash = json_parser.parse(File.read(filename))
+      hash || {} # hint
+      # should exist because the file did, even if it didn't
+      # contain anything
+    rescue FFI_Yajl::ParseError => e
+      Ohai::Log.error("Could not parse hint file at #{filename}: #{e.message}")
     end
 
     def self.hint?(name)
-      @hints ||= Hash.new
+      @hints ||= {}
       return @hints[name] if @hints[name]
-
       Ohai.config[:hints_path].each do |path|
         filename = File.join(path, "#{name}.json")
-        if File.exist?(filename)
-          begin
-            json_parser = FFI_Yajl::Parser.new
-            hash = json_parser.parse(File.read(filename))
-            @hints[name] = hash || Hash.new # hint
-            # should exist because the file did, even if it didn't
-            # contain anything
-          rescue FFI_Yajl::ParseError => e
-            Ohai::Log.error("Could not parse hint file at #{filename}: #{e.message}")
-          end
-        end
+        next unless File.exist?(filename)
+        Ohai::Log.debug("Found hint #{name}.json at #{filename}")
+        @hints[name] = parse_hint_file(filename)
       end
 
+      Ohai::Log.debug("Did not find hint #{name}.json in the hint path(s): #{Ohai.config[:hints_path].join(', ')} ") unless @hints.key?(name)
       @hints[name]
     end
   end
