@@ -16,11 +16,11 @@
 # limitations under the License.
 #
 
-require 'chef-config/path_helper'
-require 'ohai/log'
-require 'ohai/mash'
-require 'ohai/dsl'
-require 'pathname'
+require "chef-config/path_helper"
+require "ohai/log"
+require "ohai/mash"
+require "ohai/dsl"
+require "pathname"
 
 module Ohai
 
@@ -35,11 +35,24 @@ module Ohai
     # specified by calling `require_plugin` with a relative path. To manage
     # this, we track the path and root of each file as we discover them so we
     # can feed this into the v6 "dependency solver" as we load them.
-    class PluginFile < Struct.new(:path, :plugin_root)
+    PluginFile = Struct.new(:path, :plugin_root) do
 
       # Finds all the *.rb files under the configured paths in :plugin_path
       def self.find_all_in(plugin_dir)
-        Dir[File.join(ChefConfig::PathHelper.escape_glob(plugin_dir), "**", "*.rb")].map do |file|
+        unless Dir.exist?(plugin_dir)
+          Ohai::Log.warn("The plugin path #{plugin_dir} does not exist. Skipping...")
+          return []
+        end
+
+        Ohai::Log.debug("Searching for Ohai plugins in #{plugin_dir}")
+
+        # escape_glob_dir does not exist in 12.7 or below
+        if ChefConfig::PathHelper.respond_to?(:escape_glob_dir)
+          escaped = ChefConfig::PathHelper.escape_glob_dir(plugin_dir)
+        else
+          escaped = ChefConfig::PathHelper.escape_glob(plugin_dir)
+        end
+        Dir[File.join(escaped, "**", "*.rb")].map do |file|
           new(file, plugin_dir)
         end
       end
@@ -95,10 +108,11 @@ module Ohai
     # If `plugin_dir_path` is given, and the file at `plugin_path` is a v6
     # plugin, the 'relative path' of the plugin (used by `require_plugin()`) is
     # computed by finding the relative path from `plugin_dir_path` to `plugin_path`
-    def load_plugin_class(plugin_path, plugin_dir_path=nil)
+    def load_plugin_class(plugin_path, plugin_dir_path = nil)
       # Read the contents of the plugin to understand if it's a V6 or V7 plugin.
       contents = ""
       begin
+        Ohai::Log.debug("Loading plugin at #{plugin_path}")
         contents << IO.read(plugin_path)
       rescue IOError, Errno::ENOENT
         Ohai::Log.warn("Unable to open or read plugin at #{plugin_path}")
@@ -167,7 +181,7 @@ For more information visit here: docs.chef.io/ohai_custom.html")
 
     def load_v7_plugin_class(contents, plugin_path)
       plugin_class = eval(contents, TOPLEVEL_BINDING, plugin_path)
-      unless plugin_class.kind_of?(Class) and plugin_class < Ohai::DSL::Plugin
+      unless plugin_class.kind_of?(Class) && plugin_class < Ohai::DSL::Plugin
         raise Ohai::Exceptions::IllegalPluginDefinition, "Plugin file cannot contain any statements after the plugin definition"
       end
       plugin_class.sources << plugin_path
