@@ -16,27 +16,41 @@
 # limitations under the License.
 #
 
-require 'ohai/exception'
-require 'ohai/config'
-require 'ohai/log'
-require 'stringio'
-require 'tmpdir'
-require 'fcntl'
-require 'etc'
-require 'mixlib/shellout'
+require "ohai/exception"
+require "ohai/config"
+require "ohai/log"
+require "stringio"
+require "tmpdir"
+require "fcntl"
+require "etc"
+require "mixlib/shellout"
 
 module Ohai
   module Mixin
     module Command
-      def shell_out(cmd)
-        m = Mixlib::ShellOut.new(cmd)
-        m.run_command
-        m
+      # DISCLAIMER: Logging only works in the context of a plugin!!
+      # accept a command and any of the mixlib-shellout options
+      def shell_out(cmd, **options)
+        # unless specified by the caller timeout after 30 seconds
+        options[:timeout] ||= 30
+        so = Mixlib::ShellOut.new(cmd, options)
+        begin
+          so.run_command
+          Ohai::Log.debug("Plugin #{self.name}: ran '#{cmd}' and returned #{so.exitstatus}")
+          so
+        rescue Errno::ENOENT => e
+          Ohai::Log.debug("Plugin #{self.name}: ran '#{cmd}' and failed #{e.inspect}")
+          raise Ohai::Exceptions::Exec, e
+        rescue Mixlib::ShellOut::CommandTimeout => e
+          Ohai::Log.debug("Plugin #{self.name}: ran '#{cmd}' and timed out after #{options[:timeout]} seconds")
+          raise Ohai::Exceptions::Exec, e
+        end
       end
 
       module_function :shell_out
 
-      def run_command(args={})
+      def run_command(args = {})
+        Ohai::Log.warn("Ohai::Mixin::Command run_command is deprecated and will be removed in Ohai 9.0.0")
         if args.has_key?(:creates)
           if File.exists?(args[:creates])
             Ohai::Log.debug("Skipping #{args[:command]} - creates #{args[:creates]} exists.")
@@ -69,7 +83,7 @@ module Ohai
 
           args[:returns] ||= 0
           args[:no_status_check] ||= false
-          if status.exitstatus != args[:returns] and not args[:no_status_check]
+          if status.exitstatus != args[:returns] && (not args[:no_status_check])
             raise Ohai::Exceptions::Exec, "#{args[:command_string]} returned #{status.exitstatus}, expected #{args[:returns]}"
           else
             Ohai::Log.debug("Ran #{args[:command_string]} (#{args[:command]}) returned #{status.exitstatus}")
@@ -123,12 +137,13 @@ module Ohai
       # The original appears in external/open4.rb in its unmodified form.
       #
       # Thanks Ara!
-      def popen4(cmd, args={}, &b)
+      def popen4(cmd, args = {}, &b)
+        Ohai::Log.warn("Ohai::Mixin::Command popen4 is deprecated and will be removed in Ohai 9.0.0")
 
-	## Disable garbage collection to work around possible bug in MRI
-  # Ruby 1.8 suffers from intermittent segfaults believed to be due to GC while IO.select
-  # See OHAI-330 / CHEF-2916 / CHEF-1305
-	GC.disable
+        # Disable garbage collection to work around possible bug in MRI
+        # Ruby 1.8 suffers from intermittent segfaults believed to be due to GC while IO.select
+        # See OHAI-330 / CHEF-2916 / CHEF-1305
+        GC.disable
 
         # Waitlast - this is magic.
         #
@@ -162,7 +177,7 @@ module Ohai
           $VERBOSE = nil
           ps.last.fcntl(Fcntl::F_SETFD, Fcntl::FD_CLOEXEC)
 
-          cid = fork {
+          cid = fork do
             Process.setsid
 
             pw.last.close
@@ -189,7 +204,7 @@ module Ohai
               Process.uid = args[:user]
             end
 
-            args[:environment].each do |key,value|
+            args[:environment].each do |key, value|
               ENV[key] = value
             end
 
@@ -204,19 +219,19 @@ module Ohai
               else
                 exec(cmd)
               end
-              raise 'forty-two'
+              raise "forty-two"
             rescue Exception => e
               Marshal.dump(e, ps.last)
               ps.last.flush
             end
-            ps.last.close unless (ps.last.closed?)
+            ps.last.close unless ps.last.closed?
             exit!
-          }
+          end
         ensure
           $VERBOSE = verbose
         end
 
-        [pw.first, pr.last, pe.last, ps.last].each{|fd| fd.close}
+        [pw.first, pr.last, pe.last, ps.last].each { |fd| fd.close }
 
         begin
           e = Marshal.load ps.first
@@ -325,15 +340,15 @@ module Ohai
               # have encoding methods.
               if "".respond_to?(:force_encoding) && defined?(Encoding)
                 o.string.force_encoding(Encoding.default_external)
-                o.string.encode!('UTF-8', :invalid => :replace, :undef => :replace, :replace => '?')
+                o.string.encode!("UTF-8", :invalid => :replace, :undef => :replace, :replace => "?")
                 e.string.force_encoding(Encoding.default_external)
-                e.string.encode!('UTF-8', :invalid => :replace, :undef => :replace, :replace => '?')
+                e.string.encode!("UTF-8", :invalid => :replace, :undef => :replace, :replace => "?")
               end
               b[cid, pi[0], o, e]
               results.last
             end
           ensure
-            pi.each{|fd| fd.close unless fd.closed?}
+            pi.each { |fd| fd.close unless fd.closed? }
           end
         else
           [cid, pw.last, pr.first, pe.first]
@@ -341,8 +356,8 @@ module Ohai
       rescue Errno::ENOENT
         raise Ohai::Exceptions::Exec, "command #{cmd} doesn't exist or is not in the PATH"
       ensure
-	# we disabled GC entering
-	GC.enable
+        # we disabled GC entering
+        GC.enable
       end
 
       module_function :popen4
