@@ -23,7 +23,7 @@ class String
   # This should implement the same functionality as underscore method in
   # ActiveSupport::CoreExtensions::String::Inflections
   def wmi_underscore
-     self.gsub(/::/, '/').gsub(/([A-Z]+)([A-Z][a-z])/,'\1_\2').
-     gsub(/([a-z\d])([A-Z])/,'\1_\2').tr("-", "_").downcase
+    self.gsub(/::/, "/").gsub(/([A-Z]+)([A-Z][a-z])/, '\1_\2').
+      gsub(/([a-z\d])([A-Z])/, '\1_\2').tr("-", "_").downcase
   end
 end
