@@ -17,14 +17,14 @@
 # limitations under the License.
 #
 
-require 'ohai/mixin/os'
+require "ohai/mixin/os"
 
 Ohai.plugin(:OS) do
   provides "os", "os_version"
-  depends 'kernel'
+  depends "kernel"
 
   collect_data(:aix) do
     os collect_os
-    os_version kernel[:version]
+    os_version shell_out("oslevel -s").stdout.strip
   end
 end
