@@ -17,7 +17,7 @@
 #
 
 Ohai.plugin(:Memory) do
-  provides 'memory'
+  provides "memory"
 
   collect_data(:darwin) do
     memory Mash.new
@@ -30,24 +30,24 @@ Ohai.plugin(:Memory) do
     inactive = 0
     vm_stat = shell_out("vm_stat").stdout
     vm_stat_match = /page size of (\d+) bytes/.match(vm_stat)
-    page_size = if vm_stat_match and vm_stat_match[1]
+    page_size = if vm_stat_match && vm_stat_match[1]
                   vm_stat_match[1].to_i
                 else
                   4096
                 end
 
     vm_stat.split("\n").each do |line|
-      ['wired down', 'active', 'inactive'].each do |match|
+      ["wired down", "active", "inactive"].each do |match|
         unless line.index("Pages #{match}:").nil?
           pages = line.split.last.to_i
           megabyte_val = (pages * page_size) / 1024 / 1024.0
           total_consumed += megabyte_val
           case match
-          when 'wired down'
+          when "wired down"
             active += megabyte_val.to_i
-          when 'active'
+          when "active"
             active += megabyte_val.to_i
-          when 'inactive'
+          when "inactive"
             inactive += megabyte_val.to_i
           end
         end
@@ -61,4 +61,3 @@ Ohai.plugin(:Memory) do
     memory[:free] = "#{free_memory.to_i}MB" if total_consumed > 0
   end
 end
-
