@@ -14,7 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-require 'ohai/mixin/gce_metadata'
+require "ohai/mixin/gce_metadata"
 
 Ohai.plugin(:GCE) do
   include Ohai::Mixin::GCEMetadata
@@ -27,7 +27,7 @@ Ohai.plugin(:GCE) do
   # true:: If gce metadata server found
   # false:: Otherwise
   def has_gce_metadata?
-    can_metadata_connect?(Ohai::Mixin::GCEMetadata::GCE_METADATA_ADDR,80)
+    can_metadata_connect?(Ohai::Mixin::GCEMetadata::GCE_METADATA_ADDR, 80)
   end
 
   # Identifies gce
@@ -36,16 +36,16 @@ Ohai.plugin(:GCE) do
   # true:: If gce can be identified
   # false:: Otherwise
   def looks_like_gce?
-    hint?('gce') || has_gce_metadata?
+    hint?("gce") || has_gce_metadata?
   end
 
   collect_data do
     if looks_like_gce?
-      Ohai::Log.debug("looks_like_gce? == true")
+      Ohai::Log.debug("Plugin GCE: looks_like_gce? == true")
       gce Mash.new
-      fetch_metadata.each {|k, v| gce[k] = v }
+      fetch_metadata.each { |k, v| gce[k] = v }
     else
-      Ohai::Log.debug("looks_like_gce? == false")
+      Ohai::Log.debug("Plugin GCE: looks_like_gce? == false")
       false
     end
   end
