@@ -18,21 +18,21 @@
 
 Ohai.plugin(:Groovy) do
   provides "languages/groovy"
-
   depends "languages"
 
   collect_data do
-    output = nil
-
-    groovy = Mash.new
-
-    so = shell_out("groovy -v")
-    if so.exitstatus == 0
-      output = so.stdout.split
-      if output.length >= 2
-        groovy[:version] = output[2]
+    begin
+      so = shell_out("groovy -v")
+      # Sample output:
+      # Groovy Version: 2.4.6 JVM: 1.8.0_60 Vendor: Oracle Corporation OS: Mac OS X
+      if so.exitstatus == 0 && so.stdout =~ /Groovy Version: (\S+).*JVM: (\S+)/
+        groovy = Mash.new
+        groovy[:version] = $1
+        groovy[:jvm] = $2
+        languages[:groovy] = groovy
       end
-      languages[:groovy] = groovy if groovy[:version]
+    rescue Ohai::Exceptions::Exec
+      Ohai::Log.debug('Groovy plugin: Could not shell_out "groovy -v". Skipping plugin')
     end
   end
 end
