@@ -35,7 +35,7 @@ Ohai.plugin(:BlockDevice) do
             File.open("/sys/block/#{dir}/device/#{check}") { |f| block[dir][check] = f.read_nonblock(1024).strip }
           end
         end
-        %w{rotational}.each do |check|
+        %w{rotational physical_block_size logical_block_size}.each do |check|
           if File.exists?("/sys/block/#{dir}/queue/#{check}")
             File.open("/sys/block/#{dir}/queue/#{check}") { |f| block[dir][check] = f.read_nonblock(1024).strip }
           end
