@@ -46,11 +46,11 @@ Ohai.plugin(:Network) do
   end
 
   def is_openvz?
-    ::File.directory?('/proc/vz')
+    ::File.directory?("/proc/vz")
   end
 
   def is_openvz_host?
-    is_openvz? && ::File.directory?('/proc/bc')
+    is_openvz? && ::File.directory?("/proc/bc")
   end
 
   def extract_neighbors(family, iface, neigh_attr)
@@ -98,7 +98,7 @@ Ohai.plugin(:Network) do
           Ohai::Log.debug("Skipping route entry without a device: '#{line}'")
           next
         end
-        route_int = 'venet0:0' if is_openvz? && !is_openvz_host? && route_int == 'venet0' && iface['venet0:0']
+        route_int = "venet0:0" if is_openvz? && !is_openvz_host? && route_int == "venet0" && iface["venet0:0"]
 
         unless iface[route_int]
           Ohai::Log.debug("Skipping previously unseen interface from 'ip route show': #{route_int}")
@@ -107,13 +107,21 @@ Ohai.plugin(:Network) do
 
         route_entry = Mash.new(:destination => route_dest,
                                :family => family[:name])
-        %w[via scope metric proto src].each do |k|
+        %w{via scope metric proto src}.each do |k|
           route_entry[k] = $1 if route_ending =~ /\b#{k}\s+([^\s]+)\b/
         end
 
         # a sanity check, especially for Linux-VServer, OpenVZ and LXC:
         # don't report the route entry if the src address isn't set on the node
-        next if route_entry[:src] and not iface[route_int][:addresses].has_key? route_entry[:src]
+        # unless the interface has no addresses of this type at all
+        if route_entry[:src]
+          addr = iface[route_int][:addresses]
+          unless addr.nil? || addr.has_key?(route_entry[:src]) ||
+              addr.values.all? { |a| a["family"] != family[:name] }
+            Ohai::Log.debug("Skipping route entry whose src does not match the interface IP")
+            next
+          end
+        end
 
         iface[route_int][:routes] = Array.new unless iface[route_int][:routes]
         iface[route_int][:routes] << route_entry
@@ -126,6 +134,7 @@ Ohai.plugin(:Network) do
   # for information, default routes can be of this form :
   # - default via 10.0.2.4 dev br0
   # - default dev br0  scope link
+  # - default dev eth0  scope link src 1.1.1.1
   # - default via 10.0.3.1 dev eth1  src 10.0.3.2  metric 10
   # - default via 10.0.4.1 dev eth2  src 10.0.4.2  metric 20
 
@@ -141,19 +150,19 @@ Ohai.plugin(:Network) do
   # determine layer 1 details for the interface using ethtool
   def ethernet_layer_one(iface)
     return iface unless ethtool_binary = find_ethtool_binary
-    keys = %w[ Speed Duplex Port Transceiver Auto-negotiation MDI-X ]
+    keys = %w{ Speed Duplex Port Transceiver Auto-negotiation MDI-X }
     iface.each_key do |tmp_int|
-      next unless iface[tmp_int][:encapsulation] == 'Ethernet'
+      next unless iface[tmp_int][:encapsulation] == "Ethernet"
       so = shell_out("#{ethtool_binary} #{tmp_int}")
       so.stdout.lines do |line|
         line.chomp!
         Ohai::Log.debug("Parsing ethtool output: #{line}")
         line.lstrip!
-        k, v = line.split(': ')
+        k, v = line.split(": ")
         next unless keys.include? k
-        k.downcase!.tr!('-', '_')
-        if k == 'speed'
-          k = 'link_speed'   # This is not necessarily the maximum speed the NIC supports
+        k.downcase!.tr!("-", "_")
+        if k == "speed"
+          k = "link_speed" # This is not necessarily the maximum speed the NIC supports
           v = v[/\d+/].to_i
         end
         iface[tmp_int][k] = v
@@ -162,6 +171,36 @@ Ohai.plugin(:Network) do
     iface
   end
 
+  # determine ring parameters for the interface using ethtool
+  def ethernet_ring_parameters(iface)
+    return iface unless ethtool_binary = find_ethtool_binary
+    iface.each_key do |tmp_int|
+      next unless iface[tmp_int][:encapsulation] == "Ethernet"
+      so = shell_out("#{ethtool_binary} -g #{tmp_int}")
+      Ohai::Log.debug("Parsing ethtool output: #{so.stdout}")
+      type = nil
+      iface[tmp_int]["ring_params"] = {}
+      so.stdout.lines.each do |line|
+        next if line.start_with?("Ring parameters for")
+        next if line.strip.nil?
+        if line =~ /Pre-set maximums/
+          type = "max"
+          next
+        end
+        if line =~ /Current hardware settings/
+          type = "current"
+          next
+        end
+        key, val = line.split(/:\s+/)
+        if type && val
+          ring_key = "#{type}_#{key.downcase.tr(' ', '_')}"
+          iface[tmp_int]["ring_params"][ring_key] = val.to_i
+        end
+      end
+    end
+    iface
+  end
+
   # determine link stats, vlans, queue length, and state for an interface using ip
   def link_statistics(iface, net_counters)
     so = shell_out("ip -d -s link")
@@ -181,7 +220,7 @@ Ohai.plugin(:Network) do
         net_counters[tmp_int][int][:packets] = $2
         net_counters[tmp_int][int][:errors] = $3
         net_counters[tmp_int][int][:drop] = $4
-        if (int == :rx)
+        if int == :rx
           net_counters[tmp_int][int][:overrun] = $5
         else
           net_counters[tmp_int][int][:carrier] = $5
@@ -196,7 +235,7 @@ Ohai.plugin(:Network) do
         net_counters[tmp_int][:tx][:queuelen] = $1
       end
 
-      if line =~ /vlan id (\d+)/ or line =~ /vlan protocol ([\w\.]+) id (\d+)/
+      if line =~ /vlan id (\d+)/ || line =~ /vlan protocol ([\w\.]+) id (\d+)/
         if $2
           tmp_prot = $1
           tmp_id = $2
@@ -214,7 +253,7 @@ Ohai.plugin(:Network) do
       end
 
       if line =~ /state (\w+)/
-        iface[tmp_int]['state'] = $1.downcase
+        iface[tmp_int]["state"] = $1.downcase
       end
     end
     iface
@@ -258,7 +297,7 @@ Ohai.plugin(:Network) do
       iface[cint][:encapsulation] = linux_encaps_lookup($1)
       unless $2 == "00:00:00:00:00:00"
         iface[cint][:addresses] = Mash.new unless iface[cint][:addresses]
-        iface[cint][:addresses][$2.upcase] = {"family" => "lladdr"}
+        iface[cint][:addresses][$2.upcase] = { "family" => "lladdr" }
       end
     end
   end
@@ -279,7 +318,7 @@ Ohai.plugin(:Network) do
 
       iface[cint] = Mash.new unless iface[cint] # Create the fake alias interface if needed
       iface[cint][:addresses] = Mash.new unless iface[cint][:addresses]
-      iface[cint][:addresses][tmp_addr] = {"family" => "inet", "prefixlen" => tmp_prefix}
+      iface[cint][:addresses][tmp_addr] = { "family" => "inet", "prefixlen" => tmp_prefix }
       iface[cint][:addresses][tmp_addr][:netmask] = IPAddr.new("255.255.255.255").mask(tmp_prefix.to_i).to_s
 
       if line =~ /peer (\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})/
@@ -301,55 +340,88 @@ Ohai.plugin(:Network) do
   end
 
   def parse_ip_addr_inet6_line(cint, iface, line)
-    if line =~ /inet6 ([a-f0-9\:]+)\/(\d+) scope (\w+)/
+    if line =~ /inet6 ([a-f0-9\:]+)\/(\d+) scope (\w+)( .*)?/
       iface[cint][:addresses] = Mash.new unless iface[cint][:addresses]
       tmp_addr = $1
-      iface[cint][:addresses][tmp_addr] = {"family" => "inet6", "prefixlen" => $2, "scope" => ($3.eql?("host") ? "Node" : $3.capitalize)}
+      tags = $4 || ""
+      tags = tags.split(" ")
+
+      iface[cint][:addresses][tmp_addr] = {
+        "family" => "inet6",
+        "prefixlen" => $2,
+        "scope" => ($3.eql?("host") ? "Node" : $3.capitalize),
+        "tags" => tags,
+      }
     end
   end
 
   # returns the macaddress for interface from a hash of interfaces (iface elsewhere in this file)
   def get_mac_for_interface(interfaces, interface)
-    interfaces[interface][:addresses].select{|k,v| v["family"]=="lladdr"}.first.first unless interfaces[interface][:flags].include? "NOARP"
+    interfaces[interface][:addresses].select { |k, v| v["family"] == "lladdr" }.first.first unless interfaces[interface][:addresses].nil? || interfaces[interface][:flags].include?("NOARP")
   end
 
   # returns the default route with the lowest metric (unspecified metric is 0)
   def choose_default_route(routes)
-    default_route = routes.select do |r|
+    routes.select do |r|
       r[:destination] == "default"
-    end.sort do |x,y|
+    end.sort do |x, y|
       (x[:metric].nil? ? 0 : x[:metric].to_i) <=> (y[:metric].nil? ? 0 : y[:metric].to_i)
     end.first
   end
 
+  def interface_has_no_addresses_in_family?(iface, family)
+    return true if iface[:addresses].nil?
+    iface[:addresses].values.all? { |addr| addr["family"] != family }
+  end
+
+  def interface_have_address?(iface, address)
+    return false if iface[:addresses].nil?
+    iface[:addresses].key?(address)
+  end
+
+  def interface_address_not_link_level?(iface, address)
+    !iface[:addresses][address][:scope].casecmp("link").zero?
+  end
+
+  def interface_valid_for_route?(iface, address, family)
+    return true if interface_has_no_addresses_in_family?(iface, family)
+
+    interface_have_address?(iface, address) && interface_address_not_link_level?(iface, address)
+  end
+
+  def route_is_valid_default_route?(route, default_route)
+    # if the route destination is a default route, it's good
+    return true if route[:destination] == "default"
+
+    # the default route has a gateway and the route matches the gateway
+    !default_route[:via].nil? && IPAddress(route[:destination]).include?(IPAddress(default_route[:via]))
+  end
+
   # ipv4/ipv6 routes are different enough that having a single algorithm to select the favored route for both creates unnecessary complexity
   # this method attempts to deduce the route that is most important to the user, which is later used to deduce the favored values for {ip,mac,ip6}address
   # we only consider routes that are default routes, or those routes that get us to the gateway for a default route
   def favored_default_route(routes, iface, default_route, family)
     routes.select do |r|
       if family[:name] == "inet"
-        # selecting routes for ipv4
-        # using the source field when it's specified :
-        # 1) in the default route
-        # 2) in the route entry used to reach the default gateway
-        r[:src] and # it has a src field
-          iface[r[:dev]] and # the iface exists
-          iface[r[:dev]][:addresses].has_key? r[:src] and # the src ip is set on the node
-          iface[r[:dev]][:addresses][r[:src]][:scope].downcase != "link" and # this isn't a link level addresse
-          ( r[:destination] == "default" or
-            ( default_route[:via] and # the default route has a gateway
-              IPAddress(r[:destination]).include? IPAddress(default_route[:via]) # the route matches the gateway
-              )
-            )
+        # the route must have a source address
+        next if r[:src].nil? || r[:src].empty?
+
+        # the interface specified in the route must exist
+        route_interface = iface[r[:dev]]
+        next if route_interface.nil? # the interface specified in the route must exist
+
+        # the interface must have no addresses, or if it has the source address, the address must not
+        # be a link-level address
+        next unless interface_valid_for_route?(route_interface, r[:src], "inet")
+
+        # the route must either be a default route, or it must have a gateway which is accessible via the route
+        next unless route_is_valid_default_route?(r, default_route)
+
+        true
       elsif family[:name] == "inet6"
-        # selecting routes for ipv6
-        iface[r[:dev]] and # the iface exists
-          iface[r[:dev]][:state] == "up" and # the iface is up
-          ( r[:destination] == "default" or
-            ( default_route[:via] and # the default route has a gateway
-              IPAddress(r[:destination]).include? IPAddress(default_route[:via]) # the route matches the gateway
-              )
-            )
+        iface[r[:dev]] &&
+          iface[r[:dev]][:state] == "up" &&
+          route_is_valid_default_route?(r, default_route)
       end
     end.sort_by do |r|
       # sorting the selected routes:
@@ -365,7 +437,7 @@ Ohai.plugin(:Network) do
          IPAddress( r[:destination] == "default" ? family[:default_route] : r[:destination] ).prefix
        rescue
          0
-       end
+       end,
       ]
     end.first
   end
@@ -374,7 +446,7 @@ Ohai.plugin(:Network) do
   # If the 'ip' binary is available, this plugin may set {ip,mac,ip6}address. The network plugin should not overwrite these.
   # The older code section below that relies on the deprecated net-tools, e.g. netstat and ifconfig, provides less functionality.
   collect_data(:linux) do
-    require 'ipaddr'
+    require "ipaddr"
 
     iface = Mash.new
     net_counters = Mash.new
@@ -386,7 +458,7 @@ Ohai.plugin(:Network) do
 
     # ohai.plugin[:network][:default_route_table] = 'default'
     if configuration(:default_route_table).nil? || configuration(:default_route_table).empty?
-      default_route_table = 'main'
+      default_route_table = "main"
     else
       default_route_table = configuration(:default_route_table)
     end
@@ -403,14 +475,14 @@ Ohai.plugin(:Network) do
                     :name => "inet",
                     :default_route => "0.0.0.0/0",
                     :default_prefix => :default,
-                    :neighbour_attribute => :arp
+                    :neighbour_attribute => :arp,
                   }]
 
       families << {
                     :name => "inet6",
                     :default_route => "::/0",
                     :default_prefix => :default_inet6,
-                    :neighbour_attribute => :neighbour_inet6
+                    :neighbour_attribute => :neighbour_inet6,
                   } if ipv6_enabled?
 
       parse_ip_addr(iface)
@@ -429,12 +501,12 @@ Ohai.plugin(:Network) do
 
         default_route = choose_default_route(routes)
 
-        if default_route.nil? or default_route.empty?
-          attribute_name == if family[:name] == "inet"
-                              "default_interface"
-                            else
-                              "default_#{family[:name]}_interface"
-                            end
+        if default_route.nil? || default_route.empty?
+          attribute_name = if family[:name] == "inet"
+                             "default_interface"
+                           else
+                             "default_#{family[:name]}_interface"
+                           end
           Ohai::Log.debug("Unable to determine '#{attribute_name}' as no default routes were found for that interface family")
         else
           network["#{default_prefix}_interface"] = default_route[:dev]
@@ -476,7 +548,7 @@ Ohai.plugin(:Network) do
       begin
         so = shell_out("route -n")
         route_result = so.stdout.split($/).grep( /^0.0.0.0/ )[0].split( /[ \t]+/ )
-        network[:default_gateway], network[:default_interface] = route_result.values_at(1,7)
+        network[:default_gateway], network[:default_interface] = route_result.values_at(1, 7)
       rescue Ohai::Exceptions::Exec
         Ohai::Log.debug("Unable to determine default interface")
       end
@@ -559,6 +631,7 @@ Ohai.plugin(:Network) do
     end # end "ip else net-tools" block
 
     iface = ethernet_layer_one(iface)
+    iface = ethernet_ring_parameters(iface)
     counters[:network][:interfaces] = net_counters
     network["interfaces"] = iface
   end
