@@ -16,30 +16,28 @@
 # limitations under the License.
 #
 
-require 'ohai/util/file_helper'
-require 'ohai/mixin/dmi_decode'
-
-include Ohai::Util::FileHelper
-include Ohai::Mixin::DmiDecode
+require "ohai/mixin/dmi_decode"
 
 Ohai.plugin(:Virtualization) do
+  include Ohai::Mixin::DmiDecode
   provides "virtualization"
 
   def lxc_version_exists?
-    which('lxc-version')
+    which("lxc-version")
   end
 
   def docker_exists?
-    which('docker')
+    which("docker")
+  end
+
+  def nova_exists?
+    which("nova")
   end
 
   collect_data(:linux) do
     virtualization Mash.new unless virtualization
     virtualization[:systems] = Mash.new unless virtualization[:systems]
 
-    # if it is possible to detect paravirt vs hardware virt, it should be put in
-    # virtualization[:mechanism]
-
     ## Xen
     # /proc/xen is an empty dir for EL6 + Linode Guests + Paravirt EC2 instances
     if File.exist?("/proc/xen")
@@ -60,18 +58,13 @@ Ohai.plugin(:Virtualization) do
     # Xen Notes:
     # - cpuid of guests, if we could get it, would also be a clue
     # - may be able to determine if under paravirt from /dev/xen/evtchn (See OHAI-253)
-    # - EL6 guests carry a 'hypervisor' cpu flag
     # - Additional edge cases likely should not change the above assumptions
     #   but rather be additive - btm
 
-    # Detect from kernel module
+    # Detect Virtualbox from kernel module
     if File.exist?("/proc/modules")
       modules = File.read("/proc/modules")
-      if modules =~ /^kvm/
-        virtualization[:system] = "kvm"
-        virtualization[:role] = "host"
-        virtualization[:systems][:kvm] = "host"
-      elsif modules =~ /^vboxdrv/
+      if modules =~ /^vboxdrv/
         virtualization[:system] = "vbox"
         virtualization[:role] = "host"
         virtualization[:systems][:vbox] = "host"
@@ -82,11 +75,14 @@ Ohai.plugin(:Virtualization) do
       end
     end
 
-    # Detect KVM/QEMU from cpuinfo, report as KVM
-    # We could pick KVM from 'Booting paravirtualized kernel on KVM' in dmesg
-    # 2.6.27-9-server (intrepid) has this / 2.6.18-6-amd64 (etch) does not
-    # It would be great if we could read pv_info in the kernel
-    # Wait for reply to: http://article.gmane.org/gmane.comp.emulators.kvm.devel/27885
+    # if nova binary is present we're on an openstack host
+    if nova_exists?
+      virtualization[:system] = "openstack"
+      virtualization[:role] = "host"
+      virtualization[:systems][:openstack] = "host"
+    end
+
+    # Detect paravirt KVM/QEMU from cpuinfo, report as KVM
     if File.exist?("/proc/cpuinfo")
       if File.read("/proc/cpuinfo") =~ /QEMU Virtual CPU|Common KVM processor|Common 32-bit KVM processor/
         virtualization[:system] = "kvm"
@@ -95,6 +91,19 @@ Ohai.plugin(:Virtualization) do
       end
     end
 
+    # Detect KVM systems via /sys
+    # guests will have the hypervisor cpu feature that hosts don't have
+    if File.exist?("/sys/devices/virtual/misc/kvm")
+      virtualization[:system] = "kvm"
+      if File.read("/proc/cpuinfo") =~ /hypervisor/
+        virtualization[:role] = "guest"
+        virtualization[:systems][:kvm] = "guest"
+      else
+        virtualization[:role] = "host"
+        virtualization[:systems][:kvm] = "host"
+      end
+    end
+
     # Detect OpenVZ / Virtuozzo.
     # http://wiki.openvz.org/BC_proc_entries
     if File.exist?("/proc/bc/0")
@@ -118,11 +127,11 @@ Ohai.plugin(:Virtualization) do
 
     # parse dmidecode to discover various virtualization guests
     if File.exist?("/usr/sbin/dmidecode")
-      guest = guest_from_dmi(shell_out('dmidecode').stdout)
+      guest = guest_from_dmi(shell_out("dmidecode").stdout)
       if guest
         virtualization[:system] = guest
-        virtualization[:role] = 'guest'
-        virtualization[:systems][guest.to_sym] = 'guest'
+        virtualization[:role] = "guest"
+        virtualization[:systems][guest.to_sym] = "guest"
       end
     end
 
@@ -163,7 +172,7 @@ Ohai.plugin(:Virtualization) do
     if File.exist?("/proc/self/cgroup")
       cgroup_content = File.read("/proc/self/cgroup")
       if cgroup_content =~ %r{^\d+:[^:]+:/(lxc|docker)/.+$} ||
-         cgroup_content =~ %r{^\d+:[^:]+:/[^/]+/(lxc|docker)-.+$}
+          cgroup_content =~ %r{^\d+:[^:]+:/[^/]+/(lxc|docker)-.+$}
         virtualization[:system] = $1
         virtualization[:role] = "guest"
         virtualization[:systems][$1.to_sym] = "guest"
@@ -185,5 +194,15 @@ Ohai.plugin(:Virtualization) do
       virtualization[:role] = "guest"
       virtualization[:systems][:docker] = "guest"
     end
+
+    # Detect LXD
+    # See https://github.com/lxc/lxd/blob/master/doc/dev-lxd.md
+    if File.exist?("/dev/lxd/sock")
+      virtualization[:system] = "lxd"
+      virtualization[:role] = "guest"
+    elsif File.exist?("/var/lib/lxd/devlxd")
+      virtualization[:system] = "lxd"
+      virtualization[:role] = "host"
+    end
   end
 end
