@@ -6,9 +6,9 @@
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# 
+#
 #     http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -20,7 +20,7 @@ Ohai.plugin(:Ohai) do
   provides "chef_packages/ohai"
 
   collect_data do
-    require 'ohai'
+    require "ohai"
 
     chef_packages Mash.new unless chef_packages
     chef_packages[:ohai] = Mash.new
