@@ -17,19 +17,19 @@
 #
 
 Ohai.plugin(:CPU) do
-  provides 'cpu'
+  provides "cpu"
 
   collect_data(:openbsd) do
     cpuinfo = Mash.new
 
-    # OpenBSD provides most cpu information via sysctl, the only thing we need to 
-    # to scrape from dmesg.boot is the cpu feature list. 
+    # OpenBSD provides most cpu information via sysctl, the only thing we need to
+    # to scrape from dmesg.boot is the cpu feature list.
     # cpu0: FPU,V86,DE,PSE,TSC,MSR,MCE,CX8,SEP,MTRR,PGE,MCA,CMOV,PAT,CFLUSH,DS,ACPI,MMX,FXSR,SSE,SSE2,SS,TM,SBF,EST,TM2
 
     File.open("/var/run/dmesg.boot").each do |line|
       case line
       when /cpu\d+:\s+([A-Z]+$|[A-Z]+,.*$)/
-        cpuinfo["flags"] = $1.downcase.split(',')
+        cpuinfo["flags"] = $1.downcase.split(",")
       end
     end
 
