@@ -16,11 +16,11 @@
 # limitations under the License.
 #
 
-require 'ohai/mixin/os'
+require "ohai/mixin/os"
 
 Ohai.plugin(:OS) do
   provides "os", "os_version"
-  depends 'kernel'
+  depends "kernel"
 
   collect_data do
     os collect_os
