@@ -1,8 +1,8 @@
 
-require 'etc'
+require "etc"
 
 Ohai.plugin(:Passwd) do
-  provides 'etc', 'current_user'
+  provides "etc", "current_user"
 
   def fix_encoding(str)
     str.force_encoding(Encoding.default_external) if str.respond_to?(:force_encoding)
@@ -18,14 +18,14 @@ Ohai.plugin(:Passwd) do
 
       Etc.passwd do |entry|
         user_passwd_entry = Mash.new(:dir => entry.dir, :gid => entry.gid, :uid => entry.uid, :shell => entry.shell, :gecos => entry.gecos)
-        user_passwd_entry.each_value {|v| fix_encoding(v)}
+        user_passwd_entry.each_value { |v| fix_encoding(v) }
         entry_name = fix_encoding(entry.name)
         etc[:passwd][entry_name] = user_passwd_entry unless etc[:passwd].has_key?(entry_name)
       end
 
       Etc.group do |entry|
         group_entry = Mash.new(:gid => entry.gid,
-                               :members => entry.mem.map {|u| fix_encoding(u)})
+                               :members => entry.mem.map { |u| fix_encoding(u) })
 
         etc[:group][fix_encoding(entry.name)] = group_entry
       end
