@@ -16,17 +16,17 @@
 # limitations under the License.
 
 Ohai.plugin(:RootGroup) do
-  provides 'root_group'
+  provides "root_group"
 
-  require 'ohai/util/win32/group_helper' if RUBY_PLATFORM =~ /mswin|mingw32|windows/
+  require "ohai/util/win32/group_helper" if RUBY_PLATFORM =~ /mswin|mingw32|windows/
 
   collect_data do
-    case ::RbConfig::CONFIG['host_os']
+    case ::RbConfig::CONFIG["host_os"]
     when /mswin|mingw32|windows/
       group = Ohai::Util::Win32::GroupHelper.windows_root_group_name
       root_group group
     else
-      root_group Etc.getgrgid(Etc.getpwnam('root').gid).name
+      root_group Etc.getgrgid(Etc.getpwnam("root").gid).name
     end
   end
 end
