@@ -18,7 +18,6 @@
 
 Ohai.plugin(:Ruby) do
   provides "languages/ruby"
-
   depends "languages"
 
   def run_ruby(command)
@@ -43,7 +42,7 @@ Ohai.plugin(:Ruby) do
       :host_os => "RbConfig::CONFIG['host_os']",
       :host_vendor => "RbConfig::CONFIG['host_vendor']",
       :bin_dir => "RbConfig::CONFIG['bindir']",
-      :ruby_bin => "::File.join(RbConfig::CONFIG['bindir'], RbConfig::CONFIG['ruby_install_name'])"
+      :ruby_bin => "::File.join(RbConfig::CONFIG['bindir'], RbConfig::CONFIG['ruby_install_name'])",
     }
 
     # Create a query string from above hash
@@ -56,8 +55,8 @@ Ohai.plugin(:Ruby) do
     result = run_ruby "puts %Q(#{env_string})"
 
     # Parse results to plugin hash
-    result.split(',').each do |entry|
-      key, value = entry.split('=')
+    result.split(",").each do |entry|
+      key, value = entry.split("=")
       languages[:ruby][key.to_sym] = value || ""
     end
 
@@ -66,9 +65,9 @@ Ohai.plugin(:Ruby) do
     ruby_bin = languages[:ruby][:ruby_bin]
     gem_binaries = [
                     run_ruby("require 'rubygems'; puts ::Gem.default_exec_format % 'gem'"),
-                    "gem"
-                   ].map {|bin| ::File.join(bin_dir, bin)}
-    gem_binary = gem_binaries.find {|bin| ::File.exists? bin }
+                    "gem",
+                   ].map { |bin| ::File.join(bin_dir, bin) }
+    gem_binary = gem_binaries.find { |bin| ::File.exists? bin }
     if gem_binary
       languages[:ruby][:gems_dir] = run_ruby "puts %x{#{ruby_bin} #{gem_binary} env gemdir}.chomp!"
       languages[:ruby][:gem_bin] = gem_binary
