@@ -18,12 +18,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-require 'ohai/mixin/softlayer_metadata'
+require "ohai/mixin/softlayer_metadata"
 
 Ohai.plugin(:Softlayer) do
   include ::Ohai::Mixin::SoftlayerMetadata
 
-  provides 'softlayer'
+  provides "softlayer"
 
   # Identifies the softlayer cloud
   #
@@ -31,17 +31,18 @@ Ohai.plugin(:Softlayer) do
   # true:: If the softlayer cloud can be identified
   # false:: Otherwise
   def looks_like_softlayer?
-    hint?('softlayer')
+    hint?("softlayer")
   end
 
   collect_data do
     # Adds softlayer Mash
     if looks_like_softlayer?
-      ::Ohai::Log.debug("looks_like_softlayer? == true")
+      Ohai::Log.debug("Plugin Softlayer: looks_like_softlayer? == true")
       metadata = fetch_metadata
       softlayer Mash.new
-      metadata.each { |k,v| softlayer[k] = v } if metadata
+      metadata.each { |k, v| softlayer[k] = v } if metadata
+    else
+      Ohai::Log.debug("Plugin Softlayer: looks_like_softlayer? == false")
     end
-
   end
-end
\ No newline at end of file
+end
