@@ -28,8 +28,8 @@ Ohai.plugin(:SSHHostKey) do
       [ "rsa", nil ]
     when /^ecdsa/
       [ "ecdsa", content[0] ]
-    when 'ssh-ed25519'
-      [ 'ed25519', nil ]
+    when "ssh-ed25519"
+      [ "ed25519", nil ]
     else
       [ nil, nil ]
     end
@@ -51,7 +51,7 @@ Ohai.plugin(:SSHHostKey) do
     if sshd_config
       File.open(sshd_config) do |conf|
         conf.each_line do |line|
-          if line.match(/^hostkey\s/i)
+          if line =~ /^hostkey\s/i
             pub_file = "#{line.split[1]}.pub"
             content = IO.read(pub_file).split
             key_type, key_subtype = extract_keytype?(content)
