@@ -24,11 +24,12 @@
 # limitations under the License.
 #
 
-require 'ohai/mixin/seconds_to_human'
+require "ohai/mixin/seconds_to_human"
 
 Ohai.plugin(:Uptime) do
   provides "uptime", "uptime_seconds"
   provides "idletime", "idletime_seconds" # linux only
+  depends "platform_version"
 
   def collect_uptime(path)
     # kern.boottime: { sec = 1232765114, usec = 823118 } Fri Jan 23 18:45:14 2009
@@ -43,7 +44,7 @@ Ohai.plugin(:Uptime) do
   end
 
   collect_data(:hpux, :default) do
-    require 'sigar'
+    require "sigar"
 
     sigar = Sigar.new
     uptime = sigar.uptime.uptime
@@ -94,11 +95,15 @@ Ohai.plugin(:Uptime) do
   end
 
   collect_data(:windows) do
-    require 'wmi-lite/wmi'
+    require "wmi-lite/wmi"
     wmi = WmiLite::Wmi.new
-    uptime_seconds wmi.first_of('Win32_PerfFormattedData_PerfOS_System')['systemuptime'].to_i
+    if platform_version.to_f >= 6.0 ## for newer version of Windows starting from Windows Server 2008 ##
+      last_boot_up_time = wmi.first_of("Win32_OperatingSystem")["lastbootuptime"]
+      uptime_seconds Time.new.to_i - Time.parse(last_boot_up_time).to_i
+    else ## for older version of Windows starting from Windows Server 2003 ##
+      uptime_seconds wmi.first_of("Win32_PerfFormattedData_PerfOS_System")["systemuptime"].to_i
+    end
     uptime seconds_to_human(uptime_seconds)
   end
 
 end
-
