@@ -17,7 +17,7 @@
 # limitations under the License
 #
 
-require 'ohai/dsl'
+require "ohai/dsl"
 
 module Ohai
   class Runner
@@ -50,7 +50,7 @@ module Ohai
         raise
       rescue SystemExit # abort or exit from plug-in should exit Ohai with failure code
         raise
-      rescue Exception,Errno::ENOENT => e
+      rescue Exception, Errno::ENOENT => e
         Ohai::Log.debug("Plugin #{plugin.name} threw exception #{e.inspect} #{e.backtrace.join("\n")}")
       end
     end
@@ -63,7 +63,7 @@ module Ohai
 
     def run_v7_plugin(plugin)
       visited = [ plugin ]
-      while !visited.empty?
+      until visited.empty?
         next_plugin = visited.pop
 
         next if next_plugin.has_run?
@@ -76,9 +76,9 @@ module Ohai
 
         # Remove the already ran plugins from dependencies if force is not set
         # Also remove the plugin that we are about to run from dependencies as well.
-        dependency_providers.delete_if { |dep_plugin|
+        dependency_providers.delete_if do |dep_plugin|
           dep_plugin.has_run? || dep_plugin.eql?(next_plugin)
-        }
+        end
 
         if dependency_providers.empty?
           @safe_run ? next_plugin.safe_run : next_plugin.run
