@@ -21,19 +21,19 @@ module Ohai
     module Win32
       if RUBY_PLATFORM =~ /mswin|mingw|windows/
 
-        require 'ffi'
+        require "ffi"
 
         extend FFI::Library
 
-        ffi_lib 'advapi32'
+        ffi_lib "advapi32"
 
         attach_function :lookup_account_sid,
-        :LookupAccountSidA,[ :pointer, :pointer, :pointer, :pointer, :pointer, :pointer, :pointer ], :long
+        :LookupAccountSidA, [ :pointer, :pointer, :pointer, :pointer, :pointer, :pointer, :pointer ], :long
 
         attach_function :convert_string_sid_to_sid,
-        :ConvertStringSidToSidA,[ :pointer, :pointer ], :long
+        :ConvertStringSidToSidA, [ :pointer, :pointer ], :long
 
-        ffi_lib 'kernel32'
+        ffi_lib "kernel32"
 
         attach_function :local_free,
         :LocalFree, [ :pointer ], :long
