@@ -15,11 +15,11 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-require File.expand_path(File.dirname(__FILE__) + '/../../../spec_helper.rb')
+require File.expand_path(File.dirname(__FILE__) + "/../../../spec_helper.rb")
 
 describe Ohai::System, "AIX filesystem plugin" do
   before(:each) do
-    @df_Pk_LPAR = <<-DF_PK
+    @df_pk_lpar = <<-DF_PK
 Filesystem    1024-blocks      Used Available Capacity Mounted on
 /dev/hd4          2097152    219796   1877356      11% /
 /dev/hd2          5242880   2416828   2826052      47% /usr
@@ -46,7 +46,7 @@ Filesystem    1024-blocks      Used Available Capacity Mounted on
 /dev/fslv12      10485760    272376  10213384       3% /wpars/toolchain-tester-5c969f/var
 DF_PK
 
-    @df_Pk_WPAR = <<-DF_PK
+    @df_pk_wpar = <<-DF_PK
 Filesystem    1024-blocks      Used Available Capacity Mounted on
 Global           10485760    130872  10354888       2% /
 Global            5242880     39572   5203308       1% /home
@@ -57,7 +57,7 @@ Global            5242880   2725048   2517832      52% /usr
 Global           10485760    272376  10213384       3% /var
 DF_PK
 
-    @mount_LPAR = <<-MOUNT
+    @mount_lpar = <<-MOUNT
   node       mounted        mounted over    vfs       date        options
 -------- ---------------  ---------------  ------ ------------ ---------------
          /dev/hd4         /                jfs2   Jul 17 13:22 rw,log=/dev/hd8
@@ -71,7 +71,7 @@ DF_PK
 192.168.1.11 /stage/middleware /stage/middleware nfs3   Jul 17 13:24 ro,bg,hard,intr,sec=sys
 MOUNT
 
-    @mount_WPAR = <<-MOUNT
+    @mount_wpar = <<-MOUNT
   node       mounted        mounted over    vfs       date        options
 -------- ---------------  ---------------  ------ ------------ ---------------
          Global           /                jfs2   Nov 23 21:03 rw,log=NULL
@@ -89,125 +89,125 @@ MOUNT
     @plugin[:filesystem] = Mash.new
   end
 
-  context 'when run within an LPAR' do
+  context "when run within an LPAR" do
     before do
-      allow(@plugin).to receive(:shell_out).with("df -Pk").and_return(mock_shell_out(0, @df_Pk_LPAR, nil))
-      allow(@plugin).to receive(:shell_out).with("mount").and_return(mock_shell_out(0, @mount_LPAR, nil))
+      allow(@plugin).to receive(:shell_out).with("df -Pk").and_return(mock_shell_out(0, @df_pk_lpar, nil))
+      allow(@plugin).to receive(:shell_out).with("mount").and_return(mock_shell_out(0, @mount_lpar, nil))
       @plugin.run
     end
 
     describe "df -Pk" do
 
       it "returns the filesystem block size" do
-        expect(@plugin[:filesystem]["/dev/hd4"]['kb_size']).to eq("2097152")
+        expect(@plugin[:filesystem]["/dev/hd4"]["kb_size"]).to eq("2097152")
       end
 
       it "returns the filesystem used space in kb" do
-        expect(@plugin[:filesystem]["/dev/hd4"]['kb_used']).to eq("219796")
+        expect(@plugin[:filesystem]["/dev/hd4"]["kb_used"]).to eq("219796")
       end
 
       it "returns the filesystem available space in kb" do
-        expect(@plugin[:filesystem]["/dev/hd4"]['kb_available']).to eq("1877356")
+        expect(@plugin[:filesystem]["/dev/hd4"]["kb_available"]).to eq("1877356")
       end
 
       it "returns the filesystem capacity in percentage" do
-        expect(@plugin[:filesystem]["/dev/hd4"]['percent_used']).to eq("11%")
+        expect(@plugin[:filesystem]["/dev/hd4"]["percent_used"]).to eq("11%")
       end
 
       it "returns the filesystem mounted location" do
-        expect(@plugin[:filesystem]["/dev/hd4"]['mount']).to eq("/")
+        expect(@plugin[:filesystem]["/dev/hd4"]["mount"]).to eq("/")
       end
     end
 
     describe "mount" do
 
       it "returns the filesystem mount location" do
-        expect(@plugin[:filesystem]["/dev/hd4"]['mount']).to eq("/")
+        expect(@plugin[:filesystem]["/dev/hd4"]["mount"]).to eq("/")
       end
 
       it "returns the filesystem type" do
-        expect(@plugin[:filesystem]["/dev/hd4"]['fs_type']).to eq("jfs2")
+        expect(@plugin[:filesystem]["/dev/hd4"]["fs_type"]).to eq("jfs2")
       end
 
       it "returns the filesystem mount options" do
-        expect(@plugin[:filesystem]["/dev/hd4"]['mount_options']).to eq(["rw", "log=/dev/hd8"])
+        expect(@plugin[:filesystem]["/dev/hd4"]["mount_options"]).to eq(["rw", "log=/dev/hd8"])
       end
 
       # For entries like 192.168.1.11 /stage/middleware /stage/middleware nfs3   Jul 17 13:24 ro,bg,hard,intr,sec=sys
       context "having node values" do
 
         it "returns the filesystem mount location" do
-          expect(@plugin[:filesystem]["192.168.1.11:/stage/middleware"]['mount']).to eq("/stage/middleware")
+          expect(@plugin[:filesystem]["192.168.1.11:/stage/middleware"]["mount"]).to eq("/stage/middleware")
         end
 
         it "returns the filesystem type" do
-          expect(@plugin[:filesystem]["192.168.1.11:/stage/middleware"]['fs_type']).to eq("nfs3")
+          expect(@plugin[:filesystem]["192.168.1.11:/stage/middleware"]["fs_type"]).to eq("nfs3")
         end
 
         it "returns the filesystem mount options" do
-          expect(@plugin[:filesystem]["192.168.1.11:/stage/middleware"]['mount_options']).to eq(["ro", "bg", "hard", "intr", "sec=sys"])
+          expect(@plugin[:filesystem]["192.168.1.11:/stage/middleware"]["mount_options"]).to eq(["ro", "bg", "hard", "intr", "sec=sys"])
         end
       end
     end
   end
 
-  context 'when run within a WPAR' do
+  context "when run within a WPAR" do
     before do
-      allow(@plugin).to receive(:shell_out).with("df -Pk").and_return(mock_shell_out(0, @df_Pk_WPAR, nil))
-      allow(@plugin).to receive(:shell_out).with("mount").and_return(mock_shell_out(0, @mount_WPAR, nil))
+      allow(@plugin).to receive(:shell_out).with("df -Pk").and_return(mock_shell_out(0, @df_pk_wpar, nil))
+      allow(@plugin).to receive(:shell_out).with("mount").and_return(mock_shell_out(0, @mount_wpar, nil))
       @plugin.run
     end
 
     describe "df -Pk" do
 
       it "returns the filesystem block size" do
-        expect(@plugin[:filesystem]["Global:/"]['kb_size']).to eq("10485760")
+        expect(@plugin[:filesystem]["Global:/"]["kb_size"]).to eq("10485760")
       end
 
       it "returns the filesystem used space in kb" do
-        expect(@plugin[:filesystem]["Global:/"]['kb_used']).to eq("130872")
+        expect(@plugin[:filesystem]["Global:/"]["kb_used"]).to eq("130872")
       end
 
       it "returns the filesystem available space in kb" do
-        expect(@plugin[:filesystem]["Global:/"]['kb_available']).to eq("10354888")
+        expect(@plugin[:filesystem]["Global:/"]["kb_available"]).to eq("10354888")
       end
 
       it "returns the filesystem capacity in percentage" do
-        expect(@plugin[:filesystem]["Global:/"]['percent_used']).to eq("2%")
+        expect(@plugin[:filesystem]["Global:/"]["percent_used"]).to eq("2%")
       end
 
       it "returns the filesystem mounted location" do
-        expect(@plugin[:filesystem]["Global:/"]['mount']).to eq("/")
+        expect(@plugin[:filesystem]["Global:/"]["mount"]).to eq("/")
       end
     end
 
     describe "mount" do
 
       it "returns the filesystem mount location" do
-        expect(@plugin[:filesystem]["Global:/"]['mount']).to eq("/")
+        expect(@plugin[:filesystem]["Global:/"]["mount"]).to eq("/")
       end
 
       it "returns the filesystem type" do
-        expect(@plugin[:filesystem]["Global:/"]['fs_type']).to eq("jfs2")
+        expect(@plugin[:filesystem]["Global:/"]["fs_type"]).to eq("jfs2")
       end
 
       it "returns the filesystem mount options" do
-        expect(@plugin[:filesystem]["Global:/"]['mount_options']).to eq(["rw", "log=NULL"])
+        expect(@plugin[:filesystem]["Global:/"]["mount_options"]).to eq(["rw", "log=NULL"])
       end
 
       # For entries like 192.168.1.11 /stage/middleware /stage/middleware nfs3   Jul 17 13:24 ro,bg,hard,intr,sec=sys
       context "having node values" do
 
         it "returns the filesystem mount location" do
-          expect(@plugin[:filesystem]["192.168.1.11:/stage/middleware"]['mount']).to eq("/stage/middleware")
+          expect(@plugin[:filesystem]["192.168.1.11:/stage/middleware"]["mount"]).to eq("/stage/middleware")
         end
 
         it "returns the filesystem type" do
-          expect(@plugin[:filesystem]["192.168.1.11:/stage/middleware"]['fs_type']).to eq("nfs3")
+          expect(@plugin[:filesystem]["192.168.1.11:/stage/middleware"]["fs_type"]).to eq("nfs3")
         end
 
         it "returns the filesystem mount options" do
-          expect(@plugin[:filesystem]["192.168.1.11:/stage/middleware"]['mount_options']).to eq(["ro", "bg", "hard", "intr", "sec=sys"])
+          expect(@plugin[:filesystem]["192.168.1.11:/stage/middleware"]["mount_options"]).to eq(["ro", "bg", "hard", "intr", "sec=sys"])
         end
       end
     end
