@@ -16,7 +16,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-require File.expand_path(File.dirname(__FILE__) + '/../../../spec_helper.rb')
+require File.expand_path(File.dirname(__FILE__) + "/../../../spec_helper.rb")
 
 describe Ohai::System, "AIX hostname plugin" do
   before(:each) do
@@ -31,4 +31,3 @@ describe Ohai::System, "AIX hostname plugin" do
     expect(@plugin[:machinename]).to eql("aix_admin")
   end
 end
-
