@@ -19,9 +19,9 @@
 #
 
 begin
-  require File.expand_path(File.dirname(__FILE__) + '/../../spec_helper.rb')
+  require File.expand_path(File.dirname(__FILE__) + "/../../spec_helper.rb")
 
-  require 'chef/version'
+  require "chef/version"
 
   describe Ohai::System, "plugin chef" do
     before(:each) do
