@@ -15,8 +15,8 @@
 # limitations under the License.
 #
 
-require File.expand_path(File.dirname(__FILE__) + '/../../spec_helper.rb')
-require 'ipaddr'
+require File.expand_path(File.dirname(__FILE__) + "/../../spec_helper.rb")
+require "ipaddr"
 
 describe "CloudAttrs object" do
   before(:each) do
@@ -24,17 +24,17 @@ describe "CloudAttrs object" do
   end
 
   let(:cloud_node) do
-    {"public_ipv4_addrs"=>["1.2.3.1"],
-     "local_ipv4_addrs"=>["1.2.4.1"],
-     "public_ipv6_addrs"=>["3ffe:505:2::1"],
-     "local_ipv6_addrs"=>["3ffe:506:2::1"],
-     "public_ipv4"=>"1.2.3.1",
-     "local_ipv4"=>"1.2.4.1",
-     "public_ipv6"=>"3ffe:505:2::1",
-     "local_ipv6"=>"3ffe:506:2::1",
-     "public_hostname"=>"myhost.somewhere.com",
-     "local_hostname"=>"my-localhost",
-     "provider"=>"my_awesome_cloud"
+    { "public_ipv4_addrs" => ["1.2.3.1"],
+      "local_ipv4_addrs" => ["1.2.4.1"],
+      "public_ipv6_addrs" => ["3ffe:505:2::1"],
+      "local_ipv6_addrs" => ["3ffe:506:2::1"],
+      "public_ipv4" => "1.2.3.1",
+      "local_ipv4" => "1.2.4.1",
+      "public_ipv6" => "3ffe:505:2::1",
+      "local_ipv6" => "3ffe:506:2::1",
+      "public_hostname" => "myhost.somewhere.com",
+      "local_hostname" => "my-localhost",
+      "provider" => "my_awesome_cloud",
      }
   end
 
@@ -52,17 +52,17 @@ describe "CloudAttrs object" do
 
   it "throws exception with a bad ipv4 address" do
     @cloud_attr_obj = ::CloudAttrs.new()
-    expect {  @cloud_attr_obj.add_ipv6_addr("somebogusstring", :public) }.to raise_error(RuntimeError)
+    expect { @cloud_attr_obj.add_ipv6_addr("somebogusstring", :public) }.to raise_error(RuntimeError)
   end
 
   it "throws exception with a bad ipv6 address" do
     @cloud_attr_obj = ::CloudAttrs.new()
-    expect {  @cloud_attr_obj.add_ipv6_addr("FEED:B0B:DEAD:BEEF", :public)  }.to raise_error(RuntimeError)
+    expect { @cloud_attr_obj.add_ipv6_addr("FEED:B0B:DEAD:BEEF", :public) }.to raise_error(RuntimeError)
   end
 
   it "throws exception with ipv6 address passed to ipv4" do
     @cloud_attr_obj = ::CloudAttrs.new()
-    expect {  @cloud_attr_obj.add_ipv4_addr("3ffe:506:2::1", :public) }.to raise_error(RuntimeError)
+    expect { @cloud_attr_obj.add_ipv4_addr("3ffe:506:2::1", :public) }.to raise_error(RuntimeError)
   end
 
   it "throws exception with ipv4 address passed to ipv6" do
@@ -70,7 +70,6 @@ describe "CloudAttrs object" do
     expect {  @cloud_attr_obj.add_ipv6_addr("1.2.3.4", :public) }.to raise_error(RuntimeError)
   end
 
-
 end
 
 describe Ohai::System, "plugin cloud" do
@@ -98,15 +97,15 @@ describe Ohai::System, "plugin cloud" do
     end
 
     it "populates cloud public ip" do
-      @plugin[:ec2]['public_ipv4'] = "174.129.150.8"
+      @plugin[:ec2]["public_ipv4"] = "174.129.150.8"
       @plugin.run
-      expect(@plugin[:cloud_v2][:public_ipv4_addrs][0]).to eq(@plugin[:ec2]['public_ipv4'])
+      expect(@plugin[:cloud_v2][:public_ipv4_addrs][0]).to eq(@plugin[:ec2]["public_ipv4"])
     end
 
     it "populates cloud private ip" do
-      @plugin[:ec2]['local_ipv4'] = "10.252.42.149"
+      @plugin[:ec2]["local_ipv4"] = "10.252.42.149"
       @plugin.run
-      expect(@plugin[:cloud_v2][:local_ipv4_addrs][0]).to eq(@plugin[:ec2]['local_ipv4'])
+      expect(@plugin[:cloud_v2][:local_ipv4_addrs][0]).to eq(@plugin[:ec2]["local_ipv4"])
     end
 
     it "populates cloud provider" do
@@ -119,13 +118,13 @@ describe Ohai::System, "plugin cloud" do
     describe "with a public IP" do
       before do
         @plugin[:gce] = Mash.new()
-        @plugin[:gce]['instance'] = Mash.new()
-        @plugin[:gce]['instance']['networkInterfaces'] = [
+        @plugin[:gce]["instance"] = Mash.new()
+        @plugin[:gce]["instance"]["networkInterfaces"] = [
           {
-            "accessConfigs" => [ {"externalIp" => "8.35.198.173", "type"=>"ONE_TO_ONE_NAT"} ],
+            "accessConfigs" => [ { "externalIp" => "8.35.198.173", "type" => "ONE_TO_ONE_NAT" } ],
             "ip" => "10.240.0.102",
-            "network"=> "projects/foo/networks/default"
-          }
+            "network" => "projects/foo/networks/default",
+          },
         ]
       end
 
@@ -148,13 +147,13 @@ describe Ohai::System, "plugin cloud" do
     describe "with no public IP" do
       before do
         @plugin[:gce] = Mash.new()
-        @plugin[:gce]['instance'] = Mash.new()
-        @plugin[:gce]['instance']['networkInterfaces'] = [
+        @plugin[:gce]["instance"] = Mash.new()
+        @plugin[:gce]["instance"]["networkInterfaces"] = [
           {
-            "accessConfigs" => [ {"externalIp" => "", "type" => "ONE_TO_ONE_NAT"} ],
+            "accessConfigs" => [ { "externalIp" => "", "type" => "ONE_TO_ONE_NAT" } ],
             "ip" => "10.240.0.102",
-            "network" => "projects/foo/networks/default"
-          }
+            "network" => "projects/foo/networks/default",
+          },
         ]
       end
 
@@ -228,19 +227,19 @@ describe Ohai::System, "plugin cloud" do
     end
 
     it "populates cloud public ip" do
-      @plugin[:linode]['public_ip'] = "174.129.150.8"
+      @plugin[:linode]["public_ip"] = "174.129.150.8"
       @plugin.run
       expect(@plugin[:cloud_v2][:public_ipv4_addrs][0]).to eq(@plugin[:linode][:public_ip])
     end
 
     it "populates cloud private ip" do
-      @plugin[:linode]['private_ip'] = "10.252.42.149"
+      @plugin[:linode]["private_ip"] = "10.252.42.149"
       @plugin.run
       expect(@plugin[:cloud_v2][:local_ipv4_addrs][0]).to eq(@plugin[:linode][:private_ip])
     end
 
     it "populates first cloud public ip" do
-      @plugin[:linode]['public_ip'] = "174.129.150.8"
+      @plugin[:linode]["public_ip"] = "174.129.150.8"
       @plugin.run
       expect(@plugin[:cloud_v2][:public_ipv4_addrs].first).to eq(@plugin[:linode][:public_ip])
     end
@@ -257,15 +256,15 @@ describe Ohai::System, "plugin cloud" do
     end
 
     it "populates cloud public ip" do
-      @plugin[:eucalyptus]['public_ipv4'] = "174.129.150.8"
+      @plugin[:eucalyptus]["public_ipv4"] = "174.129.150.8"
       @plugin.run
-      expect(@plugin[:cloud_v2][:public_ipv4_addrs][0]).to eq(@plugin[:eucalyptus]['public_ipv4'])
+      expect(@plugin[:cloud_v2][:public_ipv4_addrs][0]).to eq(@plugin[:eucalyptus]["public_ipv4"])
     end
 
     it "populates cloud private ip" do
-      @plugin[:eucalyptus]['local_ipv4'] = "10.252.42.149"
+      @plugin[:eucalyptus]["local_ipv4"] = "10.252.42.149"
       @plugin.run
-      expect(@plugin[:cloud_v2][:local_ipv4_addrs][0]).to eq(@plugin[:eucalyptus]['local_ipv4'])
+      expect(@plugin[:cloud_v2][:local_ipv4_addrs][0]).to eq(@plugin[:eucalyptus]["local_ipv4"])
     end
 
     it "populates cloud provider" do
@@ -280,37 +279,37 @@ describe Ohai::System, "plugin cloud" do
     end
 
     it "populates cloud public ip" do
-      @plugin[:azure]['public_ip'] = "174.129.150.8"
+      @plugin[:azure]["public_ip"] = "174.129.150.8"
       @plugin.run
-      expect(@plugin[:cloud_v2][:public_ipv4_addrs][0]).to eq(@plugin[:azure]['public_ip'])
+      expect(@plugin[:cloud_v2][:public_ipv4_addrs][0]).to eq(@plugin[:azure]["public_ip"])
     end
 
     it "doesn't populates cloud vm_name" do
-      @plugin[:azure]['vm_name'] = "linux-vm"
+      @plugin[:azure]["vm_name"] = "linux-vm"
       @plugin.run
-      expect(@plugin[:cloud_v2][:vm_name]).not_to eq(@plugin[:azure]['vm_name'])
+      expect(@plugin[:cloud_v2][:vm_name]).not_to eq(@plugin[:azure]["vm_name"])
     end
 
     it "populates cloud public_hostname" do
-      @plugin[:azure]['public_fqdn'] = "linux-vm-svc.cloudapp.net"
+      @plugin[:azure]["public_fqdn"] = "linux-vm-svc.cloudapp.net"
       @plugin.run
-      expect(@plugin[:cloud_v2][:public_hostname]).to eq(@plugin[:azure]['public_fqdn'])
+      expect(@plugin[:cloud_v2][:public_hostname]).to eq(@plugin[:azure]["public_fqdn"])
     end
 
     it "doesn't populate cloud public_ssh_port" do
-      @plugin[:azure]['public_ssh_port'] = "22"
+      @plugin[:azure]["public_ssh_port"] = "22"
       @plugin.run
       expect(@plugin[:cloud_v2][:public_ssh_port]).to be_nil
     end
 
     it "should not populate cloud public_ssh_port when winrm is used" do
-      @plugin[:azure]['public_winrm_port'] = "5985"
+      @plugin[:azure]["public_winrm_port"] = "5985"
       @plugin.run
       expect(@plugin[:cloud_v2][:public_ssh_port]).to be_nil
     end
 
     it "populates cloud public_winrm_port" do
-      @plugin[:azure]['public_winrm_port'] = "5985"
+      @plugin[:azure]["public_winrm_port"] = "5985"
       @plugin.run
       expect(@plugin[:cloud_v2][:public_winrm_port]).to be_nil
     end
@@ -326,10 +325,10 @@ describe Ohai::System, "plugin cloud" do
       @plugin[:digital_ocean] = Mash.new
       @plugin[:digital_ocean][:name] = "public.example.com"
       @plugin[:digital_ocean][:networks] = Mash.new
-      @plugin[:digital_ocean][:networks][:v4] = [{"ip_address" => "1.2.3.4", "type" => "public"},
-                                                 {"ip_address" => "5.6.7.8", "type" => "private"}]
-      @plugin[:digital_ocean][:networks][:v6] = [{"ip_address" => "fe80::4240:95ff:fe47:6eee", "type" => "public"},
-                                                 {"ip_address" => "fdf8:f53b:82e4::53", "type" => "private"}]
+      @plugin[:digital_ocean][:networks][:v4] = [{ "ip_address" => "1.2.3.4", "type" => "public" },
+                                                 { "ip_address" => "5.6.7.8", "type" => "private" }]
+      @plugin[:digital_ocean][:networks][:v6] = [{ "ip_address" => "fe80::4240:95ff:fe47:6eee", "type" => "public" },
+                                                 { "ip_address" => "fdf8:f53b:82e4::53", "type" => "private" }]
     end
 
     before(:each) do
@@ -345,41 +344,41 @@ describe Ohai::System, "plugin cloud" do
     end
 
     it "populates cloud public_ipv4_addrs" do
-      expect(@plugin[:cloud_v2][:public_ipv4_addrs]).to eq(@plugin[:digital_ocean][:networks][:v4].select{|ip| ip['type'] == 'public'}
-                                                                                              .map{|ip| ip['ip_address']})
-                                                       
+      expect(@plugin[:cloud_v2][:public_ipv4_addrs]).to eq(@plugin[:digital_ocean][:networks][:v4].select { |ip| ip["type"] == "public" }
+                                                                                              .map { |ip| ip["ip_address"] })
+
     end
 
     it "populates cloud local_ipv4_addrs" do
-      expect(@plugin[:cloud_v2][:local_ipv4_addrs]).to eq(@plugin[:digital_ocean][:networks][:v4].select{|ip| ip['type'] == 'private'}
-                                                                                             .map{|ip| ip['ip_address']})
-                                                      
+      expect(@plugin[:cloud_v2][:local_ipv4_addrs]).to eq(@plugin[:digital_ocean][:networks][:v4].select { |ip| ip["type"] == "private" }
+                                                                                             .map { |ip| ip["ip_address"] })
+
     end
 
     it "populates cloud public_ipv4" do
-      expect(@plugin[:cloud_v2][:public_ipv4]).to eq(@plugin[:digital_ocean][:networks][:v4].find{|ip| ip['type'] == 'public'}['ip_address'])
+      expect(@plugin[:cloud_v2][:public_ipv4]).to eq(@plugin[:digital_ocean][:networks][:v4].find { |ip| ip["type"] == "public" }["ip_address"])
     end
 
     it "populates cloud local_ipv4" do
-      expect(@plugin[:cloud_v2][:local_ipv4]).to eq(@plugin[:digital_ocean][:networks][:v4].find{|ip| ip['type'] == 'private'}['ip_address'])
+      expect(@plugin[:cloud_v2][:local_ipv4]).to eq(@plugin[:digital_ocean][:networks][:v4].find { |ip| ip["type"] == "private" }["ip_address"])
     end
 
     it "populates cloud public_ipv6_addrs" do
-      expect(@plugin[:cloud_v2][:public_ipv6_addrs]).to eq(@plugin[:digital_ocean][:networks][:v6].select{|ip| ip['type'] == 'public'}
-                                                                                              .map{|ip| ip['ip_address']})
+      expect(@plugin[:cloud_v2][:public_ipv6_addrs]).to eq(@plugin[:digital_ocean][:networks][:v6].select { |ip| ip["type"] == "public" }
+                                                                                              .map { |ip| ip["ip_address"] })
     end
 
     it "populates cloud local_ipv6_addrs" do
-      expect(@plugin[:cloud_v2][:local_ipv6_addrs]).to eq(@plugin[:digital_ocean][:networks][:v6].select{|ip| ip['type'] == 'private'}
-                                                                                             .map{|ip| ip['ip_address']})
+      expect(@plugin[:cloud_v2][:local_ipv6_addrs]).to eq(@plugin[:digital_ocean][:networks][:v6].select { |ip| ip["type"] == "private" }
+                                                                                             .map { |ip| ip["ip_address"] })
     end
 
     it "populates cloud public_ipv6" do
-      expect(@plugin[:cloud_v2][:public_ipv6]).to eq(@plugin[:digital_ocean][:networks][:v6].find{|ip| ip['type'] == 'public'}['ip_address'])
+      expect(@plugin[:cloud_v2][:public_ipv6]).to eq(@plugin[:digital_ocean][:networks][:v6].find { |ip| ip["type"] == "public" }["ip_address"])
     end
 
     it "populates cloud local_ipv6" do
-      expect(@plugin[:cloud_v2][:local_ipv6]).to eq(@plugin[:digital_ocean][:networks][:v6].find{|ip| ip['type'] == 'private'}['ip_address'])
+      expect(@plugin[:cloud_v2][:local_ipv6]).to eq(@plugin[:digital_ocean][:networks][:v6].find { |ip| ip["type"] == "private" }["ip_address"])
     end
 
     it "populates cloud provider" do
