@@ -16,8 +16,7 @@
 # limitations under the License.
 #
 
-
-require File.expand_path(File.dirname(__FILE__) + '/../../../spec_helper.rb')
+require File.expand_path(File.dirname(__FILE__) + "/../../../spec_helper.rb")
 
 describe Ohai::System, "Darwin hostname plugin" do
   before(:each) do
@@ -42,5 +41,3 @@ describe Ohai::System, "Darwin hostname plugin" do
     expect(@plugin[:domain]).to eq("bethell")
   end
 end
-
-
