@@ -16,7 +16,7 @@
 # limitations under the License.
 #
 
-require File.expand_path(File.dirname(__FILE__) + '/../../../spec_helper.rb')
+require File.expand_path(File.dirname(__FILE__) + "/../../../spec_helper.rb")
 
 describe Ohai::System, "Darwin Memory Plugin" do
   before(:each) do
@@ -47,18 +47,18 @@ Object cache: 12 hits of 139872 lookups (0% hit rate)
   end
 
   it "should set memory[:total] to 16384MB" do
-    expect(@plugin[:memory][:total]).to eq('16384MB')
+    expect(@plugin[:memory][:total]).to eq("16384MB")
   end
 
   it "should set memory[:active] to 5140MB" do
-    expect(@plugin[:memory][:active]).to eq('5140MB')
+    expect(@plugin[:memory][:active]).to eq("5140MB")
   end
 
   it "should set memory[:inactive] to 738MB" do
-    expect(@plugin[:memory][:inactive]).to eq('738MB')
+    expect(@plugin[:memory][:inactive]).to eq("738MB")
   end
 
   it "should set memory[:free] to 10504MB" do
-    expect(@plugin[:memory][:free]).to eq('10504MB')
+    expect(@plugin[:memory][:free]).to eq("10504MB")
   end
 end
