@@ -16,14 +16,13 @@
 # limitations under the License.
 #
 
-
-require File.expand_path(File.dirname(__FILE__) + '/../../../spec_helper.rb')
+require File.expand_path(File.dirname(__FILE__) + "/../../../spec_helper.rb")
 
 describe Ohai::System, "FreeBSD kernel plugin" do
   before(:each) do
     @plugin = get_plugin("kernel")
     allow(@plugin).to receive(:collect_os).and_return(:freebsd)
-    allow(@plugin).to receive(:init_kernel).and_return({:name => "freebsd"})
+    allow(@plugin).to receive(:init_kernel).and_return({ :name => "freebsd" })
     allow(@plugin).to receive(:shell_out).with("uname -i").and_return(mock_shell_out(0, "foo\n", ""))
     allow(@plugin).to receive(:shell_out).with("sysctl kern.securelevel").and_return(mock_shell_out(0, "kern.securelevel: 1", ""))
     allow(@plugin).to receive(:shell_out).with( Ohai.abs_path( "/sbin/kldstat" )).and_return(mock_shell_out(0, "  1    7 0xc0400000 97f830   kernel", ""))
