@@ -16,8 +16,7 @@
 # limitations under the License.
 #
 
-
-require File.expand_path(File.dirname(__FILE__) + '/../../../spec_helper.rb')
+require File.expand_path(File.dirname(__FILE__) + "/../../../spec_helper.rb")
 
 describe Ohai::System, "Linux hostname plugin" do
   before(:each) do
@@ -51,4 +50,3 @@ describe Ohai::System, "Linux hostname plugin" do
   end
 
 end
-
