@@ -16,16 +16,16 @@
 # limitations under the License.
 #
 
-require File.expand_path(File.dirname(__FILE__) + '/../../../spec_helper.rb')
+require File.expand_path(File.dirname(__FILE__) + "/../../../spec_helper.rb")
 
 sigar_available = begin
-  require 'sigar'
+  require "sigar"
   true
 rescue LoadError
   false
 end
 
-require 'ohai'
+require "ohai"
 
 describe Ohai::System, "Sigar network route plugin" do
 
@@ -36,18 +36,18 @@ describe Ohai::System, "Sigar network route plugin" do
       @plugin = get_plugin("sigar/network", @ohai)
       allow(@plugin).to receive(:collect_os).and_return(:sigar)
       @sigar = double("Sigar")
-      @net_info_conf={
+      @net_info_conf = {
         :default_gateway => "192.168.1.254",
         :default_gateway_interface => "eth0",
         :primary_dns => "192.168.1.254",
         :secondary_dns => "8.8.8.8",
-        :host_name => "localhost"
+        :host_name => "localhost",
       }
-      net_info=double("Sigar::NetInfo")
-      @net_info_conf.each_pair do |k,v|
+      net_info = double("Sigar::NetInfo")
+      @net_info_conf.each_pair do |k, v|
         allow(net_info).to receive(k).and_return(v)
       end
-      @net_route_conf={
+      @net_route_conf = {
         :destination => "192.168.1.0",
         :gateway => "0.0.0.0",
         :mask => "255.255.255.0",
@@ -58,13 +58,13 @@ describe Ohai::System, "Sigar network route plugin" do
         :mtu => 0,
         :window => 0,
         :irtt => 0,
-        :ifname => "eth0"
+        :ifname => "eth0",
       }
-      net_route=double("Sigar::NetRoute")
-      @net_route_conf.each_pair do |k,v|
+      net_route = double("Sigar::NetRoute")
+      @net_route_conf.each_pair do |k, v|
         allow(net_route).to receive(k).and_return(v)
       end
-      @net_interface_conf={
+      @net_interface_conf = {
         :flags => 2115,
         :destination => "192.168.1.1",
         :mtu => 1500,
@@ -77,39 +77,39 @@ describe Ohai::System, "Sigar network route plugin" do
         :tx_queue_len => 1000,
         :prefix6_length => 0,
       }
-      net_conf=double("Sigar::NetConf")
-      @net_interface_conf.each_pair do |k,v|
+      net_conf = double("Sigar::NetConf")
+      @net_interface_conf.each_pair do |k, v|
         allow(net_conf).to receive(k).and_return(v)
       end
-      @net_interface_stat={
-        :rx_bytes=>1369035618,
-        :rx_dropped=>0,
-        :rx_errors=>0,
-        :rx_frame=>0,
-        :rx_overruns=>0,
-        :rx_packets=>7271669,
-        :speed=>-1,
-        :tx_bytes=>3482843666,
-        :tx_carrier=>0,
-        :tx_collisions=>0,
-        :tx_dropped=>0,
-        :tx_errors=>0,
-        :tx_overruns=>0,
-        :tx_packets=>4392794
+      @net_interface_stat = {
+        :rx_bytes => 1369035618,
+        :rx_dropped => 0,
+        :rx_errors => 0,
+        :rx_frame => 0,
+        :rx_overruns => 0,
+        :rx_packets => 7271669,
+        :speed => -1,
+        :tx_bytes => 3482843666,
+        :tx_carrier => 0,
+        :tx_collisions => 0,
+        :tx_dropped => 0,
+        :tx_errors => 0,
+        :tx_overruns => 0,
+        :tx_packets => 4392794,
       }
-      net_stat=double("Sigar::NetStat")
-      @net_interface_stat.each_pair do |k,v|
+      net_stat = double("Sigar::NetStat")
+      @net_interface_stat.each_pair do |k, v|
         allow(net_stat).to receive(k).and_return(v)
       end
-      @net_arp_conf={
+      @net_arp_conf = {
         :address => "192.168.1.5",
         :flags => 2,
         :hwaddr => "00:15:62:96:01:D0",
         :ifname => "eth0",
         :type => "ether",
       }
-      net_arp=double("Sigar::NetArp")
-      @net_arp_conf.each_pair do |k,v|
+      net_arp = double("Sigar::NetArp")
+      @net_arp_conf.each_pair do |k, v|
         allow(net_arp).to receive(k).and_return(v)
       end
       allow(@sigar).to receive(:fqdn).and_return("localhost.localdomain")
@@ -131,10 +131,10 @@ describe Ohai::System, "Sigar network route plugin" do
     end
 
     it "should set the route details" do
-      @net_route_conf.each_pair do |k,v|
+      @net_route_conf.each_pair do |k, v|
         # Work around the above doubleing of net_route_list skipping the call to flags()
         if k == :flags
-          v="U"
+          v = "U"
           @plugin[:network][:interfaces][:eth0][:route]["192.168.1.0"][k] = v
         end
         expect(@plugin[:network][:interfaces][:eth0][:route]["192.168.1.0"]).to have_key(k)
